==> bob.bio.base-3.1.2-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.bio.base-3.1.2-py_0", 
  "python-scripts": [
    "collect_results.py", 
    "databases.py", 
    "enroll.py", 
    "evaluate.py", 
    "extract.py", 
    "fuse_scores.py", 
    "grid_search.py", 
    "preprocess.py", 
    "resources.py", 
    "score.py", 
    "verify.py"
  ], 
  "site-packages": [
    "bob.bio.base-3.1.2-py3.6.egg-info/PKG-INFO", 
    "bob.bio.base-3.1.2-py3.6.egg-info/SOURCES.txt", 
    "bob.bio.base-3.1.2-py3.6.egg-info/dependency_links.txt", 
    "bob.bio.base-3.1.2-py3.6.egg-info/entry_points.txt", 
    "bob.bio.base-3.1.2-py3.6.egg-info/not-zip-safe", 
    "bob.bio.base-3.1.2-py3.6.egg-info/requires.txt", 
    "bob.bio.base-3.1.2-py3.6.egg-info/top_level.txt", 
    "bob/bio/__init__.py", 
    "bob/bio/base/__init__.py", 
    "bob/bio/base/algorithm/Algorithm.py", 
    "bob/bio/base/algorithm/BIC.py", 
    "bob/bio/base/algorithm/Distance.py", 
    "bob/bio/base/algorithm/LDA.py", 
    "bob/bio/base/algorithm/PCA.py", 
    "bob/bio/base/algorithm/PLDA.py", 
    "bob/bio/base/algorithm/__init__.py", 
    "bob/bio/base/config/__init__.py", 
    "bob/bio/base/config/algorithm/__init__.py", 
    "bob/bio/base/config/algorithm/bic.py", 
    "bob/bio/base/config/algorithm/distance_cosine.py", 
    "bob/bio/base/config/algorithm/distance_euclidean.py", 
    "bob/bio/base/config/algorithm/lda.py", 
    "bob/bio/base/config/algorithm/pca.py", 
    "bob/bio/base/config/algorithm/pca_lda.py", 
    "bob/bio/base/config/algorithm/pca_plda.py", 
    "bob/bio/base/config/algorithm/plda.py", 
    "bob/bio/base/config/extractor/__init__.py", 
    "bob/bio/base/config/extractor/linearize.py", 
    "bob/bio/base/config/grid/__init__.py", 
    "bob/bio/base/config/grid/demanding.py", 
    "bob/bio/base/config/grid/gpu.py", 
    "bob/bio/base/config/grid/grid.py", 
    "bob/bio/base/config/grid/local.py", 
    "bob/bio/base/config/preprocessor/__init__.py", 
    "bob/bio/base/config/preprocessor/filename.py", 
    "bob/bio/base/database/__init__.py", 
    "bob/bio/base/database/database.py", 
    "bob/bio/base/database/file.py", 
    "bob/bio/base/database/filelist/__init__.py", 
    "bob/bio/base/database/filelist/driver.py", 
    "bob/bio/base/database/filelist/models.py", 
    "bob/bio/base/database/filelist/query.py", 
    "bob/bio/base/extractor/Extractor.py", 
    "bob/bio/base/extractor/Linearize.py", 
    "bob/bio/base/extractor/__init__.py", 
    "bob/bio/base/grid.py", 
    "bob/bio/base/preprocessor/Filename.py", 
    "bob/bio/base/preprocessor/Preprocessor.py", 
    "bob/bio/base/preprocessor/__init__.py", 
    "bob/bio/base/script/__init__.py", 
    "bob/bio/base/script/collect_results.py", 
    "bob/bio/base/script/enroll.py", 
    "bob/bio/base/script/evaluate.py", 
    "bob/bio/base/script/extract.py", 
    "bob/bio/base/script/fuse_scores.py", 
    "bob/bio/base/script/grid_search.py", 
    "bob/bio/base/script/preprocess.py", 
    "bob/bio/base/script/resources.py", 
    "bob/bio/base/script/score.py", 
    "bob/bio/base/script/verify.py", 
    "bob/bio/base/test/__init__.py", 
    "bob/bio/base/test/data/atnt/models.lst", 
    "bob/bio/base/test/data/atnt/probes.lst", 
    "bob/bio/base/test/data/atnt/world.lst", 
    "bob/bio/base/test/data/bic_enroller.hdf5", 
    "bob/bio/base/test/data/bic_model.hdf5", 
    "bob/bio/base/test/data/example_filelist/data/model4_session1_sample2.pos", 
    "bob/bio/base/test/data/example_filelist/dev/for_models.lst", 
    "bob/bio/base/test/data/example_filelist/dev/for_probes.lst", 
    "bob/bio/base/test/data/example_filelist/dev/for_scores.lst", 
    "bob/bio/base/test/data/example_filelist/dev/for_tnorm.lst", 
    "bob/bio/base/test/data/example_filelist/dev/for_znorm.lst", 
    "bob/bio/base/test/data/example_filelist/eval/for_models.lst", 
    "bob/bio/base/test/data/example_filelist/eval/for_probes.lst", 
    "bob/bio/base/test/data/example_filelist/eval/for_scores.lst", 
    "bob/bio/base/test/data/example_filelist/eval/for_tnorm.lst", 
    "bob/bio/base/test/data/example_filelist/eval/for_znorm.lst", 
    "bob/bio/base/test/data/example_filelist/norm/train_optional_world_1.lst", 
    "bob/bio/base/test/data/example_filelist/norm/train_optional_world_2.lst", 
    "bob/bio/base/test/data/example_filelist/norm/train_world.lst", 
    "bob/bio/base/test/data/example_filelist2/dev/for_models.lst", 
    "bob/bio/base/test/data/example_filelist2/dev/for_scores.lst", 
    "bob/bio/base/test/data/iec_enroller.hdf5", 
    "bob/bio/base/test/data/lda_model.hdf5", 
    "bob/bio/base/test/data/lda_projected.hdf5", 
    "bob/bio/base/test/data/lda_projector.hdf5", 
    "bob/bio/base/test/data/pca_model.hdf5", 
    "bob/bio/base/test/data/pca_projected.hdf5", 
    "bob/bio/base/test/data/pca_projector.hdf5", 
    "bob/bio/base/test/data/plda_enroller.hdf5", 
    "bob/bio/base/test/data/plda_model.hdf5", 
    "bob/bio/base/test/data/plda_nopca_enroller.hdf5", 
    "bob/bio/base/test/data/plda_nopca_model.hdf5", 
    "bob/bio/base/test/data/scores-nonorm-calibrated-dev", 
    "bob/bio/base/test/data/scores-nonorm-dev", 
    "bob/bio/base/test/data/scores-nonorm-fileset-dev", 
    "bob/bio/base/test/data/scores-ztnorm-calibrated-dev", 
    "bob/bio/base/test/data/scores-ztnorm-dev", 
    "bob/bio/base/test/data/scores-ztnorm-fileset-dev", 
    "bob/bio/base/test/dummy/__init__.py", 
    "bob/bio/base/test/dummy/algorithm.py", 
    "bob/bio/base/test/dummy/algorithm_noprojection.py", 
    "bob/bio/base/test/dummy/config.py", 
    "bob/bio/base/test/dummy/config2.py", 
    "bob/bio/base/test/dummy/database.py", 
    "bob/bio/base/test/dummy/extractor.py", 
    "bob/bio/base/test/dummy/filelist.py", 
    "bob/bio/base/test/dummy/fileset.py", 
    "bob/bio/base/test/dummy/grid_search.py", 
    "bob/bio/base/test/dummy/preprocessor.py", 
    "bob/bio/base/test/test_algorithms.py", 
    "bob/bio/base/test/test_config_file.py", 
    "bob/bio/base/test/test_database_implementations.py", 
    "bob/bio/base/test/test_extractor.py", 
    "bob/bio/base/test/test_filelist.py", 
    "bob/bio/base/test/test_preprocessor.py", 
    "bob/bio/base/test/test_scripts.py", 
    "bob/bio/base/test/test_tools.py", 
    "bob/bio/base/test/test_utils.py", 
    "bob/bio/base/test/utils.py", 
    "bob/bio/base/tools/FileSelector.py", 
    "bob/bio/base/tools/__init__.py", 
    "bob/bio/base/tools/algorithm.py", 
    "bob/bio/base/tools/command_line.py", 
    "bob/bio/base/tools/extractor.py", 
    "bob/bio/base/tools/grid.py", 
    "bob/bio/base/tools/preprocessor.py", 
    "bob/bio/base/tools/scoring.py", 
    "bob/bio/base/utils/__init__.py", 
    "bob/bio/base/utils/io.py", 
    "bob/bio/base/utils/resources.py", 
    "bob/bio/base/utils/singleton.py"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            fo.write('#!%s\n' % normpath(sys.executable))
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()

==> bob.bio.base-3.2.0-py_0.tar.bz2: link.py <==
DATA = {
  "Examples": [], 
  "dist": "bob.bio.base-3.2.0-py_0", 
  "python-scripts": [
    "fuse_scores.py", 
    "resources.py", 
    "enroll.py", 
    "preprocess.py", 
    "score.py", 
    "verify.py", 
    "collect_results.py", 
    "evaluate.py", 
    "databases.py", 
    "extract.py", 
    "grid_search.py"
  ], 
  "site-packages": [
    "bob.bio.base-3.2.0-py3.6.egg-info/top_level.txt", 
    "bob/bio/base/database/filelist/models.py", 
    "bob/bio/base/extractor/Extractor.py", 
    "bob/bio/base/algorithm/Distance.py", 
    "bob/bio/base/test/data/pca_projector.hdf5", 
    "bob/bio/base/config/algorithm/__init__.py", 
    "bob/bio/base/test/data/scores-nonorm-fivecol-dev", 
    "bob/bio/base/test/data/example_filelist2/dev/for_scores.lst", 
    "bob.bio.base-3.2.0-py3.6.egg-info/PKG-INFO", 
    "bob/bio/base/extractor/__init__.py", 
    "bob/bio/base/test/test_utils.py", 
    "bob/bio/base/config/grid/gpu.py", 
    "bob/bio/base/test/data/atnt/probes.lst", 
    "bob/bio/base/test/data/example_filelist/norm/train_optional_world_1.lst", 
    "bob/bio/base/preprocessor/Filename.py", 
    "bob/bio/base/test/test_scripts.py", 
    "bob/bio/base/test/data/example_filelist/dev/for_models.lst", 
    "bob.bio.base-3.2.0-py3.6.egg-info/SOURCES.txt", 
    "bob/bio/base/test/dummy/config.py", 
    "bob/bio/base/config/grid/demanding.py", 
    "bob/bio/base/config/grid/__init__.py", 
    "bob/bio/base/test/dummy/algorithm_noprojection.py", 
    "bob/bio/base/test/data/scores-ztnorm-calibrated-dev", 
    "bob/bio/base/script/resources.py", 
    "bob/bio/base/database/__init__.py", 
    "bob/bio/base/test/data/lda_model.hdf5", 
    "bob/bio/base/script/__init__.py", 
    "bob/bio/base/script/enroll.py", 
    "bob/bio/base/config/algorithm/distance_cosine.py", 
    "bob/bio/base/config/grid/grid.py", 
    "bob/bio/base/test/test_config_file.py", 
    "bob/bio/base/config/extractor/linearize.py", 
    "bob/bio/base/script/fuse_scores.py", 
    "bob/bio/base/test/data/example_filelist/eval/for_probes.lst", 
    "bob/bio/__init__.py", 
    "bob/bio/base/config/algorithm/pca.py", 
    "bob/bio/base/test/dummy/extractor.py", 
    "bob/bio/base/script/collect_results.py", 
    "bob/bio/base/test/dummy/database.py", 
    "bob.bio.base-3.2.0-py3.6.egg-info/not-zip-safe", 
    "bob/bio/base/algorithm/PLDA.py", 
    "bob/bio/base/test/data/bic_enroller.hdf5", 
    "bob/bio/base/database/file.py", 
    "bob/bio/base/test/data/iec_enroller.hdf5", 
    "bob/bio/base/config/algorithm/distance_euclidean.py", 
    "bob/bio/base/test/data/scores-ztnorm-fileset-dev", 
    "bob/bio/base/test/data/scores-nonorm-calibrated-dev", 
    "bob/bio/base/config/algorithm/plda.py", 
    "bob/bio/base/algorithm/PCA.py", 
    "bob/bio/base/test/data/pca_model.hdf5", 
    "bob/bio/base/test/test_algorithms.py", 
    "bob/bio/base/tools/FileSelector.py", 
    "bob/bio/base/config/__init__.py", 
    "bob.bio.base-3.2.0-py3.6.egg-info/entry_points.txt", 
    "bob/bio/base/test/data/example_filelist/norm/train_world.lst", 
    "bob/bio/base/test/__init__.py", 
    "bob/bio/base/config/algorithm/pca_lda.py", 
    "bob/bio/base/test/data/example_filelist/dev/for_tnorm.lst", 
    "bob/bio/base/script/preprocess.py", 
    "bob/bio/base/script/grid_search.py", 
    "bob/bio/base/config/preprocessor/__init__.py", 
    "bob/bio/base/utils/io.py", 
    "bob/bio/base/config/algorithm/pca_plda.py", 
    "bob/bio/base/database/filelist/query.py", 
    "bob/bio/base/test/test_database_implementations.py", 
    "bob/bio/base/algorithm/__init__.py", 
    "bob/bio/base/test/data/scores-ztnorm-fivecol-dev", 
    "bob/bio/base/test/data/plda_nopca_model.hdf5", 
    "bob/bio/base/test/data/scores-ztnorm-dev", 
    "bob/bio/base/test/data/example_filelist/dev/for_probes.lst", 
    "bob/bio/base/test/data/lda_projector.hdf5", 
    "bob/bio/base/test/data/lda_projected.hdf5", 
    "bob/bio/base/tools/grid.py", 
    "bob/bio/base/test/test_extractor.py", 
    "bob/bio/base/script/evaluate.py", 
    "bob/bio/base/test/data/plda_nopca_enroller.hdf5", 
    "bob/bio/base/tools/command_line.py", 
    "bob/bio/base/config/extractor/__init__.py", 
    "bob/bio/base/preprocessor/Preprocessor.py", 
    "bob/bio/base/test/data/example_filelist2/dev/for_models.lst", 
    "bob.bio.base-3.2.0-py3.6.egg-info/dependency_links.txt", 
    "bob.bio.base-3.2.0-py3.6.egg-info/requires.txt", 
    "bob/bio/base/extractor/Linearize.py", 
    "bob/bio/base/test/dummy/filelist.py", 
    "bob/bio/base/script/extract.py", 
    "bob/bio/base/tools/scoring.py", 
    "bob/bio/base/algorithm/BIC.py", 
    "bob/bio/base/database/filelist/driver.py", 
    "bob/bio/base/test/data/atnt/models.lst", 
    "bob/bio/base/test/data/pca_projected.hdf5", 
    "bob/bio/base/tools/__init__.py", 
    "bob/bio/base/test/data/example_filelist/eval/for_tnorm.lst", 
    "bob/bio/base/preprocessor/__init__.py", 
    "bob/bio/base/config/algorithm/lda.py", 
    "bob/bio/base/tools/preprocessor.py", 
    "bob/bio/base/__init__.py", 
    "bob/bio/base/test/data/plda_model.hdf5", 
    "bob/bio/base/config/grid/local.py", 
    "bob/bio/base/test/dummy/grid_search.py", 
    "bob/bio/base/database/database.py", 
    "bob/bio/base/script/score.py", 
    "bob/bio/base/test/dummy/preprocessor.py", 
    "bob/bio/base/test/data/bic_model.hdf5", 
    "bob/bio/base/tools/algorithm.py", 
    "bob/bio/base/test/data/scores-nonorm-fileset-dev", 
    "bob/bio/base/test/data/atnt/world.lst", 
    "bob/bio/base/test/dummy/config2.py", 
    "bob/bio/base/script/verify.py", 
    "bob/bio/base/test/data/example_filelist/eval/for_scores.lst", 
    "bob/bio/base/database/filelist/__init__.py", 
    "bob/bio/base/utils/resources.py", 
    "bob/bio/base/utils/singleton.py", 
    "bob/bio/base/config/algorithm/bic.py", 
    "bob/bio/base/test/dummy/algorithm.py", 
    "bob/bio/base/test/data/scores-nonorm-dev", 
    "bob/bio/base/test/data/example_filelist/dev/for_scores.lst", 
    "bob/bio/base/algorithm/Algorithm.py", 
    "bob/bio/base/test/data/scores-nonorm-openset-dev", 
    "bob/bio/base/test/data/example_filelist/eval/for_models.lst", 
    "bob/bio/base/utils/__init__.py", 
    "bob/bio/base/test/data/example_filelist/eval/for_znorm.lst", 
    "bob/bio/base/test/test_filelist.py", 
    "bob/bio/base/test/test_preprocessor.py", 
    "bob/bio/base/config/preprocessor/filename.py", 
    "bob/bio/base/test/data/plda_enroller.hdf5", 
    "bob/bio/base/test/data/example_filelist/norm/train_optional_world_2.lst", 
    "bob/bio/base/tools/extractor.py", 
    "bob/bio/base/test/data/example_filelist/data/model4_session1_sample2.pos", 
    "bob/bio/base/grid.py", 
    "bob/bio/base/algorithm/LDA.py", 
    "bob/bio/base/test/test_tools.py", 
    "bob/bio/base/test/dummy/fileset.py", 
    "bob/bio/base/test/dummy/__init__.py", 
    "bob/bio/base/test/utils.py", 
    "bob/bio/base/test/data/example_filelist/dev/for_znorm.lst"
  ]
}
## END DATA

"""
This is code that is added to noarch Python packages. See
conda_build/noarch_python.py.

"""
import os
from os.path import dirname, exists, isdir, join, normpath
import re
import sys
import shutil


# Silence pyflakes. This variable is added when link.py is written by
# conda_build.noarch_python.
if False:
    DATA = None

THIS_DIR = dirname(__file__)
PREFIX = normpath(sys.prefix)
if sys.platform == 'win32':
    BIN_DIR = join(PREFIX, 'Scripts')
    SITE_PACKAGES = 'Lib/site-packages'
else:
    BIN_DIR = join(PREFIX, 'bin')
    SITE_PACKAGES = 'lib/python%s/site-packages' % sys.version[:3]

# the list of these files is going to be store in info/_files
FILES = []

# three capture groups: whole_shebang, executable, options
SHEBANG_REGEX = (br'^(#!'  # pretty much the whole match string
                 br'(?:[ ]*)'  # allow spaces between #! and beginning of the executable path
                 br'(/(?:\\ |[^ \n\r\t])*)'  # the executable is the next text block without an escaped space or non-space whitespace character  # NOQA
                 br'(.*)'  # the rest of the line can contain option flags
                 br')$')  # end whole_shebang group


def _link(src, dst):
    try:
        os.link(src, dst)
        # on Windows os.link raises AttributeError
    except (OSError, AttributeError):
        shutil.copy2(src, dst)


def _unlink(path):
    try:
        os.unlink(path)
    except OSError:
        pass


def pyc_f(f, version_info=sys.version_info):
    if version_info[0] == 2:
        return f + 'c'
    dn, fn = f.rsplit('/', 1)
    return '%s/__pycache__/%s.cpython-%d%d.pyc' % (
              dn, fn[:-3], version_info[0], version_info[1])


def link_files(src_root, dst_root, files):
    for f in files:
        src = join(THIS_DIR, src_root, f)
        dst = join(PREFIX, dst_root, f)
        dst_dir = dirname(dst)
        if not isdir(dst_dir):
            os.makedirs(dst_dir)
        if exists(dst):
            _unlink(dst)
        _link(src, dst)
        f = '%s/%s' % (dst_root, f)
        FILES.append(f)
        if f.endswith('.py'):
            FILES.append(pyc_f(f))


# yanked from conda
def replace_long_shebang(data):
    # this function only changes a shebang line if it exists and is greater than 127 characters
    if hasattr(data, 'encode'):
        data = data.encode()
    shebang_match = re.match(SHEBANG_REGEX, data, re.MULTILINE)
    if shebang_match:
        whole_shebang, executable, options = shebang_match.groups()
        if len(whole_shebang) > 127:
            executable_name = executable.decode('utf-8').split('/')[-1]
            new_shebang = '#!/usr/bin/env %s%s' % (executable_name, options.decode('utf-8'))
            data = data.replace(whole_shebang, new_shebang.encode('utf-8'))
    if hasattr(data, 'decode'):
        data = data.decode()
    return data


def create_script(fn):
    src = join(THIS_DIR, 'python-scripts', fn)
    dst = join(BIN_DIR, fn)
    if sys.platform == 'win32':
        shutil.copy2(src, dst + '-script.py')
        FILES.append('Scripts/%s-script.py' % fn)
        shutil.copy2(join(THIS_DIR,
                          'cli-%d.exe' % (8 * tuple.__itemsize__)),
                     dst + '.exe')
        FILES.append('Scripts/%s.exe' % fn)
    else:
        with open(src) as fi:
            data = fi.read()
        with open(dst, 'w') as fo:
            shebang = replace_long_shebang('#!%s\n' % normpath(sys.executable))
            fo.write(shebang)
            fo.write(data)
        os.chmod(dst, 0o775)
        FILES.append('bin/%s' % fn)


def create_scripts(files):
    if not files:
        return
    if not isdir(BIN_DIR):
        os.mkdir(BIN_DIR)
    for fn in files:
        create_script(fn)


def main():
    create_scripts(DATA['python-scripts'])
    link_files('site-packages', SITE_PACKAGES, DATA['site-packages'])
    link_files('Examples', 'Examples', DATA['Examples'])

    with open(join(PREFIX, 'conda-meta',
                   '%s.files' % DATA['dist']), 'w') as fo:
        for f in FILES:
            fo.write('%s\n' % f)


if __name__ == '__main__':
    main()
